#!/bin/sh
#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2006, 2014. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

#-----------------------------------------------------------------------------------------------------
# Description:   Configure SQL Server Database environment during Migration
#                This file is for use on Linux or Unix bash
#                Run the script where it is located rather than running it from a different folder
# Usage:
#                createSchema.sh <dbUserName> <dbPassword>
#
# Example:
#                createSchema.sh db2admin db2admin
#-----------------------------------------------------------------------------------------------------

DB_NAME=@DB_NAME@
DB_USER=$1
DB_PASSWORD=$2

#-----------------------------------------
# Print Message
#-----------------------------------------
print_message() {
echo ===================================================================================================
echo "Usage: createSchema.sh  <dbUserName> <dbPassword> "
echo
echo "Parameters:"
echo "dbUserName        -  User who can execute sql scripts i.e., db2admin"
echo "dbPassword        -  Password for dbUser who can execute sql scripts i.e., db2admin"
echo
echo "Examples:"
echo "     1.createSchema.sh -help "
echo "     1.createSchema.sh [interactive mode] "
echo "     2.createSchema.sh  db2admin db2admin "
echo
echo ===================================================================================================
exit
}

#--------------------------------------------
# Ask user for Database password
#--------------------------------------------
get_db_password() {
   while true; do
      if [ -n "$DB_PASSWORD" ]; then
         DB_PASSWORD=$DB_PASSWORD
         break
      else
         echo
         echo "Enter DB2 PASSWORD[dbPassword] for connecting database [$DB_NAME]:"
         read DB_PASSWORD
         continue
      fi
   done
}

#--------------------------------------------
# Ask user for Database user name
#--------------------------------------------
get_db_user() {
   while true; do
      if [ -n "$DB_USER" ]; then
         DB_USER=$DB_USER
         break
      else
         echo
         echo "Enter DB2 user[dbUsername] for connecting database [$DB_NAME]:"
         read DB_USER
         continue
      fi
   done
}

if [ "$1" == "" ]; then
    print_message
fi

if [ "$1" == "-h"  -o "$1" == "-help" ] ; then
   print_message
fi


if [ $# == 0 -o $# == 2  ]; then
        DB_USER=$1
        DB_PASSWORD=$2
fi


INIT_DIR=`pwd`

CURRENT_DIR=`dirname $0`
if [ "$CURRENT_DIR" == "." ] ; then
   CURRENT_DIR=`pwd`
fi

#  Move to DB2 folder
cd $CURRENT_DIR

timestamp=$(date +"%Y%m%d%k%M%S")
PRE_LOG_FILE_NAME=result_$timestamp.log
LOG_FILE_NAME=result.log
if [ -f "$LOG_FILE_NAME" ]; then
	mv $LOG_FILE_NAME $PRE_LOG_FILE_NAME
fi

#call the following subroutine to get DB2 credentials
get_db_user
get_db_password

rm -f createTableSQL.list
rm -f createProcSQL.list

#Connect to the database specifying the id and the password
rc=0
db2 connect to $DB_NAME user $DB_USER using $DB_PASSWORD
rc=$?

if [ $rc -eq 0 ] ; then

      db2 set current schema=@SCHEMA@
      ls *.sql | grep "^createTablespace"  > createTableSpaceSQL.list
      ls *.sql | grep "^createSchema"  > createTableSQL.list
      ls *.sql | grep "^createTable_"  >> createTableSQL.list
      ls *.sql | grep "^createProcedure"  > createProcSQL.list
      for i in `cat createTableSpaceSQL.list`
      	do
        	db2 -v -z result.log -s -t -f $i
            rc=$?
            if [ $rc -eq 0 ] ; then
            	echo "Script is successful $i"
            elif [ $rc -ge 1 ] && [ $rc -le 3 ]; then
            	echo "Script $i is completed with warnings, check the result.log file for details"
            else
            	echo
                echo  "Script $i has failed. Please check the result.log file."
                echo
            fi
        done
        
      for i in `cat createTableSQL.list`
      	do
        	db2 -v -z result.log -s -t -f $i
            rc=$?
            if [ $rc -eq 0 ] ; then
            	echo "Script is successful $i"
            elif [ $rc -ge 1 ] && [ $rc -le 3 ]; then
            	echo "Script $i is completed with warnings, check the result.log file for details"
            else
            	echo
                echo  "Script $i has failed. Please check the result.log file."
                echo
            fi
        done
      for i in `cat createProcSQL.list`
      	do
        	db2 -v -z result.log -tdGO -f $i
            rc=$?
            if [ $rc -eq 0 ] ; then
            	echo "Script is successful $i"
            elif [ $rc -ge 1 ] && [ $rc -le 3 ]; then
            	echo "Script $i is completed with warnings, check the result.log file for details"
            else
            	echo
                echo  "Script $i has failed. Please check the result.log file."
                echo
            fi
        done         
else
    echo
    echo  "Check DB2 setup or Enter correct dbUserId or dbPassword or dbName"
    echo    
fi

cd $INIT_DIR
rm -f createTableSpaceSQL.list
rm -f createTableSQL.list
rm -f createProcSQL.list

exit $?
