#!/bin/sh
#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2006, 2014. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

#-----------------------------------------------------------------------------------------------------
# Description:   Configure SQL Server Database environment during Migration
#                This file is for use on Linux or Unix bash
#                Run the script where it is located rather than running it from a different folder
# Usage:
#                dropSchema.sh <dbUserName> <dbPassword> <Oracle_SID>
#
# Example:
#                dropSchema.sh dbUser dbPassword orcl
#-----------------------------------------------------------------------------------------------------

DB_NAME=$3
DB_USER=$1
DB_PASSWORD=$2

#-----------------------------------------
# Print Message
#-----------------------------------------
print_message() {
echo ===================================================================================================
echo "Usage: dropSchema.sh  <dbUserName> <dbPassword>"
echo
echo "Parameters:"
echo "dbUserName        -  User who can execute sql scripts i.e., admin"
echo "dbPassword        -  Password for dbUser who can execute sql scripts i.e., admin"
echo
echo "Examples:"
echo "     1.dropSchema.sh -help "
echo "     1.dropSchema.sh [interactive mode] "
echo "     2.dropSchema.sh  <dbUserName> <dbPassword> <Oracle_SID> "
echo
echo ===================================================================================================
exit
}

#--------------------------------------------
# Ask user for Database password
#--------------------------------------------
get_db_password() {
   while true; do
      if [ -n "$DB_PASSWORD" ]; then
         DB_PASSWORD=$DB_PASSWORD
         break
      else
         echo
         echo "Enter Oracle PASSWORD[dbPassword]:"
         read DB_PASSWORD
         continue
      fi
   done
}

#--------------------------------------------
# Ask user for Database user name
#--------------------------------------------
get_db_user() {
   while true; do
      if [ -n "$DB_USER" ]; then
         DB_USER=$DB_USER
         break
      else
         echo
         echo "Enter Oracle user[dbUsername]:"
         read DB_USER
         continue
      fi
   done
}

#--------------------------------------------
# Ask user for oracle sid
#--------------------------------------------
get_db_sid() {
	echo	
	if [ -n "$DB_NAME" ]; then
	   DB_NAME=$DB_NAME
	else
	   while true; do
	      if [ -n "$DB_NAME" ]; then
	         DB_NAME=$DB_NAME
	         break
	      else
	         echo
	         echo "Enter Oracle SID[$DB_NAME]:"
	         read DB_NAME
	         continue
	      fi
	   done
	fi
}

if ["$1" == ""]; then
    print_message
fi

if [ "$1" == "-h"  -o "$1" == "-help" ] ; then
   print_message
fi


if [ $# == 0 -o $# == 2  ]; then
	DB_USER=$1
	DB_PASSWORD=$2
fi

INIT_DIR=`pwd`

CURRENT_DIR=`dirname $0`
if [ "$CURRENT_DIR" == "." ] ; then
   CURRENT_DIR=`pwd`
fi

#  Move to Oracle folder
cd $CURRENT_DIR

timestamp=$(date +"%Y%m%d%k%M%S")
PRE_LOG_FILE_NAME=result_$timestamp.log
LOG_FILE_NAME=result.log
if [ -f "$LOG_FILE_NAME" ]; then
	mv $LOG_FILE_NAME $PRE_LOG_FILE_NAME
fi


#call the following subroutine to get oracle credentials
get_db_user
get_db_password

#call the following subroutine to get oracle sid
get_db_sid

#Connect to the database specifying the id and the password
rc=0

ls *.sql | grep "^drop" | sed s/^/\@/ > BPM_80.sql

echo quit >> BPM_80.sql

sqlplus $DB_USER/$DB_PASSWORD@$DB_NAME @BPM_80.sql

rc=$?

rm -f  BPM_80.sql

if [ $rc -ne 0 ] ; then
    echo
    echo  "dropSchema scripts have failed."
    echo    
fi

cd $INIT_DIR

exit $?
