#!/bin/sh
#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2006, 2014. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

#-----------------------------------------------------------------------------------------------------
# Description:   Configure SQL Server Database environment during Migration
#                This file is for use on Linux or Unix bash
#                Run the script where it is located rather than running it from a different folder
# Usage:
#                dropSchema.sh <dbUserName> <dbPassword> <dbHostName>
#
# Example:
#                dropSchema.sh admin admin localhost
#-----------------------------------------------------------------------------------------------------

DB_NAME=@DB_NAME@
DB_USER=$1
DB_PASSWORD=$2
DB_HOSTNAME=$3

#-----------------------------------------
# Print Message
#-----------------------------------------
print_message() {
echo ===================================================================================================
echo "Usage: dropSchema.sh  <dbUserName> <dbPassword> <dbHostName>"
echo
echo "Parameters:"
echo "dbUserName        -  User who can execute sql scripts i.e., db2admin"
echo "dbPassword        -  Password for dbUsee who can execute sql scripts i.e., db2admin"
echo "dbHostName        -  machine where SQL Server database is running"
echo
echo "Examples:"
echo "     1.dropSchema.sh -help "
echo "     1.dropSchema.sh [interactive mode] "
echo "     2.dropSchema.sh  admin admin localhost"
echo
echo ===================================================================================================
exit
}

#--------------------------------------------
# Ask user for Database password
#--------------------------------------------
get_db_password() {
   while true; do
      if [ -n "$DB_PASSWORD" ]; then
         DB_PASSWORD=$DB_PASSWORD
         break
      else
         echo
         echo "Enter SQL Server PASSWORD[dbPassword]:"
         read DB_PASSWORD
         continue
      fi
   done
}

#--------------------------------------------
# Ask user for Database user name
#--------------------------------------------
get_db_user() {
   while true; do
      if [ -n "$DB_USER" ]; then
         DB_USER=$DB_USER
         break
      else
         echo
         echo "Enter SQL Server user[dbUsername]:"
         read DB_USER
         continue
      fi
   done
}

#--------------------------------------------
# Ask user for Database host name
#--------------------------------------------
get_db_hostname() {
   while true; do
      if [ -n "$DB_HOSTNAME" ]; then
         DB_HOSTNAME=$DB_HOSTNAME
         break
      else
         echo
         echo "Enter SQL Server host name[localhost]:"
         read DB_HOSTNAME
         continue
      fi
   done
}

if ["$1" == ""]; then
    print_message
fi

if [ "$1" == "-h"  -o "$1" == "-help" ] ; then
   print_message
fi


if [ $# == 0 -o $# == 3  ] ; then
        DB_USER=$1
        DB_PASSWORD=$2
        DB_HOSTNAME=$3
fi

INIT_DIR=`pwd`

CURRENT_DIR=`dirname $0`
if [ "$CURRENT_DIR" == "." ] ; then
   CURRENT_DIR=`pwd`
fi

timestamp=$(date +"%Y%m%d%k%M%S")
PRE_LOG_FILE_NAME=result_$timestamp.log
LOG_FILE_NAME=result.log
if [ -f "$LOG_FILE_NAME" ]; then
	mv $LOG_FILE_NAME $PRE_LOG_FILE_NAME
fi


#call the following subroutine to get SQL Server credentials
get_db_user
get_db_password
get_db_hostname


#  Move to SQL folder
cd $CURRENT_DIR

SERVER_PARAM=-S $DB_HOSTNAME
if [ "$SERVER"=="" ] ; then
    SERVER_PARAM=

CONNECTION_ID=-U $DB_USER -P $DB_PASSWORD
rc=0

ls *.sql | grep "^drop"  > BPM_80.sql

for j in `cat BPM_80.sql`
do
   osql -e -b -d $DB_NAME $SERVER_PARAM $CONNECTION_ID -i$j -o result.log
   rc=$?

   if [ $rc -ne 0 ] ; then
      echo
      echo  "dropSchema scripts have failed. Please check the result.log file"
      echo
   fi

done

rm -f  BPM_80.sql

cd $INIT_DIR

exit $?
